%define pname	translate
%define oname	%{pname}-toolkit

Name:		python-%{pname}
Version:	2.4.0
Release:	%mkrel 2
Summary:	Software localization toolkit
License:	GPLv2+
Group:		Development/Python
Url:		http://toolkit.translatehouse.org/
Source0:	https://pypi.io/packages/source/t/%{oname}/%{oname}-%{version}.tar.gz
Source1:	pocommentclean.1
Source2:	pocompendium.1
Source3:	pocount.1
Source4:	pomigrate2.1
Source5:	popuretext.1
Source6:	poreencode.1
Source7:	posplit.1
Source8:	tmserver.1
BuildArch:	noarch
BuildRequires:	pkgconfig(python3)
BuildRequires:	python3-setuptools
# (Fedora) those are needed for man pages generation
BuildRequires:	python3-lxml
BuildRequires:	python3-simplejson
BuildRequires:	python3-six

%description
The Translate Toolkit is a set of software and documentation designed
to help make the lives of localizers both more productive and less
frustrating.  The Toolkit is part of the translate.sourceforge.net
project, hosted at http://translate.sourceforge.net/

The software includes programs to covert localization formats to the
common PO format and programs to check and manage PO files.  The
documentation includes guides on using the tools, running a
localization project and how to localize various projects from
OpenOffice.org to Mozilla.

At its core the software contains a set of classes for handling
various localization storage formats: DTD, properties, OpenOffice.org
GSI/SDF, CSV and of course PO.  And scripts to convert between these
formats.

Also part of the Toolkit are Python programs to create word counts,
merge translations and perform various checks on PO files.

%package -n python3-%{pname}
Summary:        Software localization toolkit
Group:          Development/Python
Requires:	python3-chardet
Requires:	python3-lxml
Requires:	python3-levenshtein
Requires:	python3-simplejson
Requires:	python3-enchant
Requires:	python3-vobject
Requires:	python3-iniparse
Requires:	python3-pycountry
# for sub2po and po2sub
Recommends:	python3-aeidon

Recommends:	python3-beautifulsoup4
Recommends:	python3-babel

Provides:	python-translate = %{version}-%{release}
Obsoletes:	python-translate < 1.13.0-3
Provides:	%{oname} = %{version}-%{release}
%{?python_provide:%python_provide python3-%{pname}}

%description -n python3-%{pname}
The Translate Toolkit is a set of software and documentation designed
to help make the lives of localizers both more productive and less
frustrating.  The Toolkit is part of the translate.sourceforge.net
project, hosted at http://translate.sourceforge.net/

The software includes programs to covert localization formats to the
common PO format and programs to check and manage PO files.  The
documentation includes guides on using the tools, running a
localization project and how to localize various projects from
OpenOffice.org to Mozilla.

At its core the software contains a set of classes for handling
various localization storage formats: DTD, properties, OpenOffice.org
GSI/SDF, CSV and of course PO.  And scripts to convert between these
formats.

Also part of the Toolkit are Python programs to create word counts,
merge translations and perform various checks on PO files.


%package	doc
Summary:	Documentation of %{oname}
Group:		Documentation
BuildArch:	noarch

%description	doc
The Translate Toolkit is a set of software and documentation designed
to help make the lives of localizers both more productive and less
frustrating.  The Toolkit is part of the translate.sourceforge.net
project, hosted at http://translate.sourceforge.net/

The software includes programs to covert localization formats to the
common PO format and programs to check and manage PO files.  The
documentation includes guides on using the tools, running a
localization project and how to localize various projects from
OpenOffice.org to Mozilla.

At its core the software contains a set of classes for handling
various localization storage formats: DTD, properties, OpenOffice.org
GSI/SDF, CSV and of course PO.  And scripts to convert between these
formats.

Also part of the Toolkit are Python programs to create word counts,
merge translations and perform various checks on PO files.

This package includes the documentation files of %{oname}.

%prep
%setup -q -n %{oname}-%{version}

%build
%py3_build

%install
%py3_install

# remove docs
%{__rm} docs/_build/html/.buildinfo

# (Fedora) create manpages
mkdir -p %{buildroot}%{_mandir}/man1
for prog in %{buildroot}%{_bindir}/*; do
    progname=$(basename $prog)
    case ${progname} in
      build_tmdb|buildxpi.py|get_moz_enUS.py|l20n2po|po2l20n|pydiff)
        ;;
      pocommentclean|pocompendium|pocount|pomigrate2|popuretext|poreencode|posplit|tmserver)
        cp -p %{_sourcedir}/${progname}.1 %{buildroot}%{_mandir}/man1/
        ;;
      *)
        PYTHONPATH=. $prog --manpage >  %{buildroot}%{_mandir}/man1/${progname}.1 || :
        grep -q .SH %{buildroot}%{_mandir}/man1/${progname}.1 || rm -f %{buildroot}%{_mandir}/man1/${progname}.1
        ;;
    esac
done

# remove documentation files from site-packages
rm -r %{buildroot}%{python3_sitelib}/translate/docs

%files -n python3-%{pname}
%doc README.rst
%{_bindir}/*
%{python3_sitelib}/*
%{_mandir}/man1/*

%files doc
%doc docs/_build/html/


%changelog
* Sun Feb 16 2020 umeabot <umeabot> 2.4.0-2.mga8
+ Revision: 1534108
- Mageia 8 Mass Rebuild

* Fri Sep 27 2019 daviddavid <daviddavid> 2.4.0-1.mga8
+ Revision: 1447327
- new version: 2.4.0
- port to python 3 (thanks fedora)

* Wed Sep 19 2018 umeabot <umeabot> 1.13.0-2.mga7
+ Revision: 1274850
- Mageia 7 Mass Rebuild

* Tue Jan 19 2016 daviddavid <daviddavid> 1.13.0-1.mga6
+ Revision: 925931
- new version: 1.13.0
- use new python macros
- update URL and Source URL
- update BRs and Rs list

* Wed Oct 15 2014 umeabot <umeabot> 1.10.0-7.mga5
+ Revision: 738843
- Second Mageia 5 Mass Rebuild

* Sat Sep 27 2014 tv <tv> 1.10.0-6.mga5
+ Revision: 729886
- rebuild for missing pythoneggs deps

* Tue Sep 16 2014 umeabot <umeabot> 1.10.0-5.mga5
+ Revision: 688384
- Mageia 5 Mass Rebuild
+ pterjan <pterjan>
- Rebuild for new Python

* Tue Oct 22 2013 umeabot <umeabot> 1.10.0-3.mga4
+ Revision: 544349
- Mageia 4 Mass Rebuild

* Tue Oct 15 2013 pterjan <pterjan> 1.10.0-2.mga4
+ Revision: 499571
- Rebuild to add different pythonegg provides for python 2 and 3

* Wed Aug 28 2013 philippem <philippem> 1.10.0-1.mga4
+ Revision: 472655
- files list change
- update to 1.10.0

* Sun Jan 13 2013 umeabot <umeabot> 1.9.0-2.mga3
+ Revision: 379581
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Wed Apr 20 2011 ahmad <ahmad> 1.9.0-1.mga1
+ Revision: 88981
- Update to 1.9.0
- Split the docs in a separate sub-package (from Michael)
- Use the upstream %%{python_sitelib} macro
- imported package python-translate


* Wed Feb 23 2011 Michael Scherer <misc@mandriva.org> 1.8.1-1mdv2011.0
+ Revision: 639460
- upgrade to 1.8.1

* Sat Oct 30 2010 Ahmad Samir <ahmadsamir@mandriva.org> 1.8.0-1mdv2011.0
+ Revision: 590594
- update to 1.8.0
- drop patches 0 and 1, merged upstream
- sync spec with Fedora:
  o change some suggests into requires
  o add BR, python-lxml and python-simplejson to generate the man pages
  o as python-psyco is only available for i586, make it only required for %%ix86
- drop obsolete python macro
- use %%pyver macro in the file list

* Tue Jul 27 2010 Ahmad Samir <ahmadsamir@mandriva.org> 1.7.0-1mdv2011.0
+ Revision: 560894
- update to 1.7.0
- add two patches from Fedora
- create manpages (Fedora)

* Tue Feb 02 2010 Frederik Himpe <fhimpe@mandriva.org> 1.5.3-1mdv2010.1
+ Revision: 499750
- update to new version 1.5.3

* Tue Jan 12 2010 Jérôme Brenier <incubusss@mandriva.org> 1.5.2-1mdv2010.1
+ Revision: 490100
- new version 1.5.2

* Wed Dec 09 2009 Jérôme Brenier <incubusss@mandriva.org> 1.5.1-2mdv2010.1
+ Revision: 475714
- Suggests : python-psyco python-simplejson python-enchant python-vobject
  python-iniparse (spotted by Alaa Abd el Fattah #56308)

* Wed Dec 09 2009 Jérôme Brenier <incubusss@mandriva.org> 1.5.1-1mdv2010.1
+ Revision: 475602
- new version 1.5.1

* Sat Nov 07 2009 Frederik Himpe <fhimpe@mandriva.org> 1.4.1-1mdv2010.1
+ Revision: 462187
- update to new version 1.4.1

* Tue Aug 11 2009 Frederik Himpe <fhimpe@mandriva.org> 1.4.0-1mdv2010.0
+ Revision: 415157
- update to new version 1.4.0

  + Per Øyvind Karlsen <peroyvind@mandriva.org>
    - add a suggests on 'python-levenshtein'

* Sat May 23 2009 Per Øyvind Karlsen <peroyvind@mandriva.org> 1.3.0-2mdv2010.0
+ Revision: 378867
- add dependency on python-lxml (required by at least pretranslate..)

* Fri Feb 13 2009 Frederik Himpe <fhimpe@mandriva.org> 1.3.0-1mdv2009.1
+ Revision: 340122
- update to new version 1.3.0

* Wed Jan 14 2009 Funda Wang <fwang@mandriva.org> 1.2.1-1mdv2009.1
+ Revision: 329483
- add provides
- New version 1.2.1

* Sun Dec 28 2008 Funda Wang <fwang@mandriva.org> 1.2.0-2mdv2009.1
+ Revision: 320351
- rebuild for new python

* Mon Oct 20 2008 Funda Wang <fwang@mandriva.org> 1.2.0-1mdv2009.1
+ Revision: 295683
- New version 1.2.0

* Mon Oct 20 2008 Funda Wang <fwang@mandriva.org> 1.0.1-5mdv2009.1
+ Revision: 295682
- should use --root rather than --prefix

* Fri Aug 01 2008 Thierry Vignaud <tv@mandriva.org> 1.0.1-4mdv2009.0
+ Revision: 259837
- rebuild

* Fri Jul 25 2008 Thierry Vignaud <tv@mandriva.org> 1.0.1-3mdv2009.0
+ Revision: 247701
- rebuild

* Thu Jan 17 2008 Olivier Blin <oblin@mandriva.com> 1.0.1-1mdv2008.1
+ Revision: 154232
- 1.0.1

* Wed Jan 02 2008 Olivier Blin <oblin@mandriva.com> 0.10.1-1mdv2008.1
+ Revision: 140738
- restore BuildRoot

  + Thierry Vignaud <tv@mandriva.org>
    - kill re-definition of %%buildroot on Pixel's request


* Fri Jan 12 2007 Olivier Blin <oblin@mandriva.com> 0.10.1-1mdv2007.0
+ Revision: 107921
- buildrequires python-devel
- initial python-translate release
- Create python-translate

